@@ -3,19 +3,21 @@ from .cache import CacheConfig
 from .compression import CompressionConfig
 from .cors import CORSConfig
 from .csrf import CSRFConfig
-from .logging import LoggingConfig
+from .logging import BaseLoggingConfig, LoggingConfig, StructLoggingConfig
 from .openapi import OpenAPIConfig
 from .static_files import StaticFilesConfig
 from .template import TemplateConfig
 
 __all__ = [
     "AppConfig",
-    "CacheConfig",
+    "BaseLoggingConfig",
     "CORSConfig",
     "CSRFConfig",
-    "OpenAPIConfig",
-    "StaticFilesConfig",
-    "TemplateConfig",
+    "CacheConfig",
     "CompressionConfig",
     "LoggingConfig",
+    "OpenAPIConfig",
+    "StaticFilesConfig",
+    "StructLoggingConfig",
+    "TemplateConfig",
 ]
