@@ -9,7 +9,7 @@ from starlite.types import ExceptionHandlersMap, Guard
 from starlite.utils import is_async_callable
 
 if TYPE_CHECKING:
-    from pydantic.typing import AnyCallable
+    from starlite.types import AnyCallable
 
 
 class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
@@ -22,7 +22,7 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
         guards: Optional[List[Guard]] = None,
         name: Optional[str] = None,
         opt: Optional[Dict[str, Any]] = None,
-    ):
+    ) -> None:
         """ASGI Route Handler decorator. Use this decorator to decorate ASGI
         apps.
 
