@@ -61,11 +61,9 @@ from starlite.types import (
 from starlite.utils import AsyncCallable, is_async_callable, is_class_and_subclass
 
 if TYPE_CHECKING:
-    from pydantic.typing import AnyCallable
-
     from starlite.app import Starlite
     from starlite.plugins import PluginProtocol
-    from starlite.types import AsyncAnyCallable
+    from starlite.types import AnyCallable, AsyncAnyCallable
 
 
 def _normalize_cookies(local_cookies: "ResponseCookies", layered_cookies: "ResponseCookies") -> List[Dict[str, Any]]:
@@ -277,7 +275,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
-    ):
+    ) -> None:
         """HTTP Route Decorator. Use this decorator to decorate an HTTP handler
         with multiple methods.
 
@@ -628,7 +626,7 @@ class get(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
-    ):
+    ) -> None:
         """GET Route Decorator. Use this decorator to decorate an HTTP handler
         for GET requests.
 
@@ -753,7 +751,7 @@ class post(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
-    ):
+    ) -> None:
         """POST Route Decorator. Use this decorator to decorate an HTTP handler
         for POST requests.
 
@@ -878,7 +876,7 @@ class put(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
-    ):
+    ) -> None:
         """PUT Route Decorator. Use this decorator to decorate an HTTP handler
         for PUT requests.
 
@@ -1003,7 +1001,7 @@ class patch(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
-    ):
+    ) -> None:
         """PATCH Route Decorator. Use this decorator to decorate an HTTP
         handler for PATCH requests.
 
@@ -1128,7 +1126,7 @@ class delete(HTTPRouteHandler):
         security: Optional[List[SecurityRequirement]] = None,
         summary: Optional[str] = None,
         tags: Optional[List[str]] = None,
-    ):
+    ) -> None:
         """DELETE Route Decorator. Use this decorator to decorate an HTTP
         handler for DELETE requests.
 
