@@ -6,6 +6,7 @@ from starlite.middleware.base import DefineMiddleware, MiddlewareProtocol
 from starlite.middleware.compression import CompressionMiddleware
 from starlite.middleware.csrf import CSRFMiddleware
 from starlite.middleware.exceptions import ExceptionHandlerMiddleware
+from starlite.middleware.rate_limit import RateLimitConfig, RateLimitMiddleware
 
 __all__ = [
     "AbstractAuthenticationMiddleware",
@@ -15,4 +16,6 @@ __all__ = [
     "DefineMiddleware",
     "ExceptionHandlerMiddleware",
     "MiddlewareProtocol",
+    "RateLimitConfig",
+    "RateLimitMiddleware",
 ]
