@@ -1,10 +1,10 @@
 from .dependency import is_dependency_field, should_skip_dependency_validation
 from .exception import get_exception_handler
 from .model import convert_dataclass_to_model, create_parsed_model_field
-from .module_loading import import_string
 from .predicates import is_async_callable, is_class_and_subclass, is_optional_union
 from .scope import get_serializer_from_scope
 from .sequence import find_index, unique
+from .serialization import default_serializer
 from .sync import AsyncCallable
 from .templates import create_template_engine
 from .url import join_paths, normalize_path
@@ -14,10 +14,10 @@ __all__ = [
     "convert_dataclass_to_model",
     "create_parsed_model_field",
     "create_template_engine",
+    "default_serializer",
     "find_index",
     "get_exception_handler",
     "get_serializer_from_scope",
-    "import_string",
     "is_async_callable",
     "is_class_and_subclass",
     "is_dependency_field",
